CLUSTER_BASELINE_DATASETS = {
    1: "breast_pca",
    2: "diabetes_pca",
    3: "german_postal_selected",
    4: "glass_pca",
    5: "iris_pca",
    6: "kc1_pca",
    7: "mfeat-fourier_pca",
    8: "ruspini_selected",
    9: "segment_pca",
    10: "wine_pca",
}

BASELINE_K_DIMENTIONS={
    "breast_pca": [2, 3, 5, 10], 
    "diabetes_pca": [2, 3, 5, 10],
    "german_postal_selected": [2, 3, 5, 10],
    "glass_pca": [2, 3, 5, 10],
    "iris_pca": [2, 3, 5, 10],
    "kc1_pca": [2, 3, 5, 10],
    "mfeat-fourier_pca": [2, 3, 5, 10],
    "ruspini_selected": [2, 3, 5, 10],
    "segment_pca": [2, 3, 5, 10],
    "wine_pca": [2, 3, 5, 10],
}
